@@ -2,6 +2,7 @@
 A package for consistent logging
 """
 from felling.src.configure_felling import configure
+from felling.src.email import send_email
 
 __name__ = "felling"
 
@@ -17,4 +18,9 @@ except ModuleNotFoundError:
 try:
     __version__ = version_getter("felling")
 except NoPackageError:
-    pass
\ No newline at end of file
+    pass
+
+
+__doc__ = """
+Felling is a package which helps with logging
+"""
\ No newline at end of file
